@@ -103,6 +103,11 @@ class BaremetalClient(base.BaremetalClient):
         """List all ports associated with the node."""
         return self._list_request('/nodes/%s/ports' % uuid)
 
+    @base.handle_errors
+    def list_node_ports_detail(self, uuid):
+        """List ports detail associated with the node."""
+        return self._list_request('/nodes/%s/ports/detail' % uuid)
+
     @base.handle_errors
     def list_nodestates(self, uuid):
         """List all existing states."""
@@ -294,12 +299,13 @@ class BaremetalClient(base.BaremetalClient):
 
         """
         node = {}
-        # Explicitly allow definition of network interface and deploy
-        # interface to allow tests to specify the required values
-        # as they hold a great deal of logic which is executed upon and
-        # they can ultimately impact test behavior.
+        # Explicitly allow definition of network interface, deploy
+        # interface, and console interface to allow tests to specify
+        # the required values as they hold a great deal of logic which
+        # is executed upon and they can ultimately impact test behavior.
         for field in ('resource_class', 'name', 'description', 'shard',
-                      'network_interface', 'deploy_interface'):
+                      'network_interface', 'deploy_interface',
+                      'console_interface'):
             if kwargs.get(field):
                 node[field] = kwargs[field]
 
