@@ -92,7 +92,7 @@ class TestNodeShardQueries(base.BaseBaremetalTest):
         _, fetched_nodes = self.client.list_nodes(shard=shard)
         fetched_node_ids = [node['uuid'] for node in fetched_nodes['nodes']]
 
-        self.assertItemsEqual(good_node_ids, fetched_node_ids)
+        self.assertCountEqual(good_node_ids, fetched_node_ids)
 
     @decorators.idempotent_id('6f1e241d-4386-4730-b9ff-28c6a3dcad31')
     def test_only_show_multiple_requested_shards(self):
@@ -108,7 +108,7 @@ class TestNodeShardQueries(base.BaseBaremetalTest):
             shard=','.join([shard, second_shard]))
         fetched_node_ids = [node['uuid'] for node in fetched_nodes['nodes']]
 
-        self.assertItemsEqual(good_node_ids, fetched_node_ids)
+        self.assertCountEqual(good_node_ids, fetched_node_ids)
         self.assertNotIn(self.bad_node_id, fetched_node_ids)
         self.assertNotIn(self.none_node_id, fetched_node_ids)
 
@@ -137,7 +137,7 @@ class TestGetAllShards(base.BaseBaremetalTest):
     def setUp(self):
         super(TestGetAllShards, self).setUp()
         _, self.chassis = self.create_chassis()
-        self.shards = ["shard1", "shard2", "shard3"]
+        self.shards = {"shard1", "shard2", "shard3"}
         self.node_ids = []
         for shard in self.shards:
             _, node = self.create_node(self.chassis['uuid'], shard=shard)
@@ -146,6 +146,6 @@ class TestGetAllShards(base.BaseBaremetalTest):
     @decorators.idempotent_id('fc786196-63c7-4e0d-bd14-3e478d4d1e3e')
     def test_get_all_shards(self):
         _, fetched_shards = self.client.get_shards()
-        fetched_shards = [shard['name'] for shard in fetched_shards['shards']]
+        fetched_shards = {shard['name'] for shard in fetched_shards['shards']}
 
-        self.assertItemsEqual(self.shards, fetched_shards)
+        self.assertTrue(self.shards.issubset(fetched_shards))
